P4 to Git Change 1548476 by cpaquot@cpaquot-ocl-lc-lnx on 2018/05/01 15:50:51

SWDEV-145570 - [HIP]
	Added support for null stream avoiding creating/destroying dummy streams.
	Added basic event class for hipEvent* support.
	Refactored some common functionality: No more direct access to g_context.
	Support hipStreamSynchronize(0).

Affected files ...

... //depot/stg/opencl/drivers/opencl/api/hip/hip_context.cpp#9 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_device_runtime.cpp#7 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_event.cpp#3 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_event.hpp#1 add
... //depot/stg/opencl/drivers/opencl/api/hip/hip_internal.hpp#8 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_memory.cpp#15 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_module.cpp#8 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_platform.cpp#9 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_stream.cpp#4 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_texture.cpp#7 edit
This commit is contained in:
foreman
2018-05-01 18:10:09 -04:00
parent dc1497535d
commit 61378a359c
10 changed files with 177 additions and 126 deletions
+19 -7
View File
@@ -22,30 +22,42 @@ THE SOFTWARE.
#include <hip/hip_runtime.h>
#include "hip_internal.hpp"
#include "hip_event.hpp"
hipError_t hipEventCreateWithFlags(hipEvent_t* event, unsigned flags) {
HIP_INIT_API(event, flags);
assert(0 && "Unimplemented");
hip::Event* e = new hip::Event(flags);
return hipErrorUnknown;
if (e == nullptr) {
return hipErrorOutOfMemory;
}
*event = reinterpret_cast<hipEvent_t>(e);
return hipSuccess;
}
hipError_t hipEventCreate(hipEvent_t* event) {
HIP_INIT_API(event);
assert(0 && "Unimplemented");
hip::Event* e = new hip::Event(0);
return hipErrorUnknown;
if (e == nullptr) {
return hipErrorOutOfMemory;
}
*event = reinterpret_cast<hipEvent_t>(e);
return hipSuccess;
}
hipError_t hipEventDestroy(hipEvent_t event) {
HIP_INIT_API(event);
assert(0 && "Unimplemented");
delete reinterpret_cast<hip::Event*>(event);
return hipErrorUnknown;
return hipSuccess;
}
hipError_t hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop) {